@@ -45,18 +45,27 @@ void ChooseListForm::on_savePushButton_clicked()
 {
     QList<QListWidgetItem * > items = ui->listWidget->findItems(ui->listNameLineEdit->text(), Qt::MatchExactly);
     QString listName = ui->listNameLineEdit->text();
-    if(items.count() == 0)
+    if(listName.isEmpty() == false)
     {
-        ui->listWidget->addItem(listName);
-    }
-    settings->setValue(listName, settings->value(LIST_TEXT, ""));
-    QString information;
-    information.append("List saved ");
-    information.append(listName);
+        if(items.count() == 0)
+        {
+            ui->listWidget->addItem(listName);
+        }
+        settings->setValue(listName, settings->value(LIST_TEXT, ""));
+        QString information;
+        information.append("List saved ");
+        information.append(listName);
 #ifdef Q_WS_MAEMO_5
-    QMaemo5InformationBox::information(this, information, QMaemo5InformationBox::DefaultTimeout);
+        QMaemo5InformationBox::information(this, information, QMaemo5InformationBox::DefaultTimeout);
 #endif
-    saveList();
+        saveList();
+    }
+    else
+    {
+#ifdef Q_WS_MAEMO_5
+        QMaemo5InformationBox::information(this, "List name can't be empty", QMaemo5InformationBox::DefaultTimeout);
+#endif
+    }
 }
 
 void ChooseListForm::on_removePushButton_clicked()
